@@ -12,7 +12,7 @@ use base 'Log::Dispatch::Email';
 
 use 5.008008;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.01_1';
 
 sub new {
     my $proto = shift;
@@ -24,8 +24,8 @@ sub new {
     $self->{host}          = delete $p{host};
     $self->{port}          = delete $p{port};
     $self->{ssl}           = delete $p{ssl};
-    $self->{sasl_username} = delete $p{sasl_username};
-    $self->{sasl_password} = delete $p{sasl_password};
+    $self->{user}          = delete $p{user};
+    $self->{pass}          = delete $p{pass};
 
     return $self;
 }
@@ -109,7 +109,7 @@ Log::Dispatch::Email::EmailSender - Subclass of Log::Dispatch::Email that uses t
                     to            => [ qw( foo@example.com bar@example.org ) ],
                     subject       => 'Big error!',
                     header_encode => 'MIME-Header-ISO_2022_JP',
-                    body_encode   => 'iso-2022-jp', ],
+                    body_encode   => 'iso-2022-jp' ]
                 ],
           );
   $log->emerg("Something bad is happening");
@@ -131,9 +131,7 @@ Log::Dispatch::Email::EmailSender - Subclass of Log::Dispatch::Email that uses t
                     body_encode   => 'iso-2022-jp',
                     use_transport => 1,
                     host          => [your smtp host],
-                    port          => [your smtp port number],
-                    sasl_username => [your username],
-                    sasl_password => [your password], ],
+                    port          => [your smtp port number] ]
                 ],
           );
   $log->emerg("Something bad is happening");
@@ -173,7 +171,7 @@ I don't understand why it doesn't work.
 
 =head1 AUTHOR
 
-keroyon E<lt>keroyon@cpan.orgE<gt>
+keroyonn E<lt>keroyonn@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
